@@ -13,8 +13,12 @@ from .plot.reactions import (
     plotReactionCount,
     plotPeerToReactionCount,
     plotReactionsOverTimeAsHeatMap,
-    plotWeeklyReactionHeatMap
+    plotWeeklyReactionHeatMap,
+    plotTopXPeersByMonth,
+    plotAccumulatedUserActivityInEachMinuteOfDay
 )
+from .model.friends import Friends
+from .plot.friends import plotMonthlyFriendsCreated
 from time import time
 
 
@@ -36,7 +40,7 @@ def _getBanner():
     '''
         Prints banner of scipt
     '''
-    print('\x1b[1;6;36;49m[+]fviz v0.2.0 - Facebook data visualiser\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
+    print('\x1b[1;6;36;49m[+]fviz v0.5.0 - Facebook data visualizer\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
 
 
 def _getCMD() -> Tuple[str, str, str]:
@@ -83,6 +87,15 @@ def main():
         if not reactions:
             raise Exception('Failed to parse reactions')
 
+        friends = Friends.fromJSON(
+            join(extractAt,
+                 'friends/friends.json'
+                 )
+        )
+
+        if not friends:
+            raise Exception('Failed to parse friends data')
+
         _success = [
             plotReactionCount(
                 reactions.reactionTypeToCount,
@@ -122,6 +135,34 @@ def main():
                     sink,
                     'weeklyAccumulatedReactionHeatMapFor{}.svg'.format(
                         _splitAndJoinActorName(reactions.reactions[0].actor)
+                    ))),
+            plotTopXPeersByMonth(
+                reactions,
+                'Top 3 profiles with highest liked and reacted post by {}'.format(
+                    reactions.reactions[0].actor),
+                join(
+                    sink,
+                    'top3ProfilesWithMonthlyMostReactedPostsBy{}.svg'.format(
+                        _splitAndJoinActorName(reactions.reactions[0].actor)
+                    ))),
+            plotAccumulatedUserActivityInEachMinuteOfDay(
+                reactions,
+                'Accumulated Likes & Reactions in each minute of Day by {}'.format(
+                    reactions.reactions[0].actor),
+                join(
+                    sink,
+                    'accumulatedAcivityInEachMinuteOfDayBy{}.svg'.format(
+                        _splitAndJoinActorName(reactions.reactions[0].actor)
+                    ))),
+            plotMonthlyFriendsCreated(
+                friends,
+                'Monthly Friending Rate of {}'.format(
+                    reactions.reactions[0].actor),
+                join(
+                    sink,
+                    'monthlyFriendingRateOf{}.svg'.format(
+                        _splitAndJoinActorName(
+                            reactions.reactions[0].actor)
                     )))
         ]
         print('[+]Completed in {} s with {}% success'.format(
